@@ -35,12 +35,15 @@ class QchDialog : public QDialog, public QDeclarativeParserStatus
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY sizeChanged)
     Q_PROPERTY(bool showProgressIndicator READ showProgressIndicator WRITE setShowProgressIndicator
                NOTIFY showProgressIndicatorChanged)
+    Q_PROPERTY(int result READ result WRITE setResult NOTIFY statusChanged)
     Q_PROPERTY(QchDialogStatus::Status status READ status NOTIFY statusChanged)
     Q_PROPERTY(QString styleSheet READ styleSheet CONSTANT FINAL)
     Q_PROPERTY(QString title READ windowTitle WRITE setWindowTitle NOTIFY titleChanged)
     Q_PROPERTY(bool visible READ isVisible WRITE setVisible NOTIFY visibleChanged)
     Q_PROPERTY(int width READ width WRITE setFixedWidth NOTIFY sizeChanged)
     
+    Q_ENUMS(DialogCode)
+    
     Q_INTERFACES(QDeclarativeParserStatus)
 
     Q_CLASSINFO("DefaultProperty", "data")
